Type Alias FrozenHashNodeGraph

pub type FrozenHashNodeGraph<N, E, NI, EI, EM, S = RandomState> = FrozenGraph<N, E, NI, EI, HashNodeMap<N, NI, EI, S>, EM>;
Available on (crate features alloc or slotmap) and crate feature std only.
A type alias for a FrozenGraph that uses a HashMap to store its nodes.

Custom hashers

FrozenHashNodeGraph supports passing a custom hasher type to HashMap via its last generic parameter S, the default is RandomState which is also the default type used by the Rust standard library.

Aliased Type

pub struct FrozenHashNodeGraph<N, E, NI, EI, EM, S = RandomState> { /* private fields */ }