Type Alias FrozenHashSlotMapGraph

pub type FrozenHashSlotMapGraph<N, E, NI, EI = EdgeIndex, S = RandomState> = FrozenHashNodeGraph<N, E, NI, EI, SlotEdgeMap<E, NI, EI>, S>;
Available on crate feature std and crate feature slotmap and (crate features alloc or slotmap) only.
A type alias for a FrozenGraph that uses a HashMap to store its nodes and a SlotMap to store its edges.

The default edge index type is EdgeIndex.

Custom hashers

FrozenHashSlotMapGraph supports passing a custom hasher type to HashMap via its last generic parameter S, the default is RandomState which is also the default type used by the Rust standard library.

Aliased Type

pub struct FrozenHashSlotMapGraph<N, E, NI, EI = EdgeIndex, S = RandomState> { /* private fields */ }