Type Alias SlotMapGraph

pub type SlotMapGraph<N, E, NI = NodeIndex, EI = EdgeIndex> = Graph<N, E, NI, EI, SlotNodeMap<N, NI, EI>, SlotEdgeMap<E, NI, EI>>;
Available on (crate features alloc or slotmap) and crate feature slotmap only.
A type alias for a Graph that uses SlotMaps to store nodes and edges.

The default node and edge index types are NodeIndex and EdgeIndex.

Aliased Type

pub struct SlotMapGraph<N, E, NI = NodeIndex, EI = EdgeIndex> { /* private fields */ }