Module error

Contains all error types provided by the crate.

Structs

NodeExistsError
An error returned when a node is added to a graph that uses a map with externally provided keys as a node map and another node exists at the specified index.
RemoveNodeError
An error returned when a node removed from a Graph can’t be removed.

Enums

AddEdgeError
An error returned when trying to add an edge to a Graph.
InvalidEdgeError
An error returned when either the source node index