Enum Entry

pub enum Entry<'a, N, NI, EI, NM>
where NI: Copy + Eq + Debug + 'static, EI: Copy + Eq + Debug + 'static, NM: MapWithEntry<Node<N, EI>, Key = NI>,
{ Occupied(OccupiedEntry<'a, N, NI, EI, NM>), Vacant(VacantEntry<'a, N, NI, EI, NM>), }
A graph node entry.

Variants



Occupied(OccupiedEntry<'a, N, NI, EI, NM>)

An occupied graph node.



Vacant(VacantEntry<'a, N, NI, EI, NM>)

A vacant graph node.

Implementations

Source

impl<'a, N, NI, EI, NM> Entry<'a, N, NI, EI, NM>
where NI: Copy + Eq + Debug + 'static, EI: Copy + Eq + Debug + 'static, NM: MapWithEntry<Node<N, EI>, Key = NI>,

pub fn or_insert(self, default: N) -> &'a mut N

Ensures a value is in the entry by inserting the default if empty, and returns a mutable reference to the value in the entry.

pub fn or_insert_with<F: FnOnce() -> N>(self, f: F) -> &'a mut N

Ensures a value is in the entry by inserting the result of the default function if empty, and returns a mutable reference to the value in the entry.