Struct OccupiedEntry

pub struct OccupiedEntry<'a, N, NI, EI, NM>
where NI: Copy + Eq + Debug + 'static, EI: Copy + Eq + Debug + 'static, NM: MapWithEntry<Node<N, EI>, Key = NI> + 'a,
{ /* private fields */ }
An occupied node entry.

Implementations

Source

impl<'a, N, NI, EI, NM> OccupiedEntry<'a, N, NI, EI, NM>
where NI: Copy + Eq + Debug + 'static, EI: Copy + Eq + Debug + 'static, NM: MapWithEntry<Node<N, EI>, Key = NI> + 'a,

pub fn get(&self) -> &N

Returns an immutable reference to the value of an entry.

pub fn get_mut(&mut self) -> &mut N

Returns a mutable reference to the value of an entry.

pub fn into_mut(self) -> &'a mut N

Converts the OccupiedEntry` into a mutable reference to the value in the entry with a lifetime bound to the map itself.

pub fn replace(&mut self, value: N) -> N

Replaces the weight of the node the entry refers to.

pub fn remove(self) -> Result<N, RemoveNodeError>

Removes a node the entry points to from the graph.

Errors

Returns a RemoveNodeError in case the node is still connected when being removed.