Contains all error types provided by the crate.
Structs
- Node
Exists Error - An error returned when a node is added to a graph that uses a map with externally provided keys as a node map and another node exists at the specified index.
- Remove
Node Error - An error returned when a node removed from a
Graphcan’t be removed.
Enums
- AddEdge
Error - An error returned when trying to add an edge to a
Graph. - Invalid
Edge Error - An error returned when either the source node index