pub struct OccupiedEntry<'a, N, NI, EI, NM>where
NI: Copy + Eq + Debug + 'static,
EI: Copy + Eq + Debug + 'static,
NM: MapWithEntry<Node<N, EI>, Key = NI> + 'a,{ /* private fields */ }Expand description
An occupied node entry.
Implementations
Sourceimpl<'a, N, NI, EI, NM> OccupiedEntry<'a, N, NI, EI, NM>
impl<'a, N, NI, EI, NM> OccupiedEntry<'a, N, NI, EI, NM>
Sourcepub fn into_mut(self) -> &'a mut N
pub fn into_mut(self) -> &'a mut N
Converts the OccupiedEntry` into a mutable reference to the value in the entry with a
lifetime bound to the map itself.
Sourcepub fn remove(self) -> Result<N, RemoveNodeError>
pub fn remove(self) -> Result<N, RemoveNodeError>
Removes a node the entry points to from the graph.
Errors
Returns a RemoveNodeError in case the node is still connected when being removed.